.. _contributing:

=====================
Contributing to shade
=====================

If you're interested in contributing to the shade project,
the following will help get you started.

Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the shade project, you need to have
signed OpenStack's contributor's agreement.

.. seealso::

   * http://wiki.openstack.org/HowToContribute
   * http://wiki.openstack.org/CLA

Project Hosting Details
-------------------------

Project Documentation
    http://docs.openstack.org/infra/shade/

Bug tracker
    http://storyboard.openstack.org

Mailing list (prefix subjects with ``[shade]`` for faster responses)
    http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-infra

Code Hosting
    https://git.openstack.org/cgit/openstack-infra/shade

Code Review
    https://review.openstack.org/#/q/status:open+project:openstack-infra/shade,n,z

    Please read `GerritWorkflow`_ before sending your first patch for review.

.. _GerritWorkflow: https://wiki.openstack.org/wiki/GerritWorkflow
